==> haskell-regex-pcre-0.95.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-pcre
version:              0.95.0.0
visibility:           public
id:                   regex-pcre-0.95.0.0-IfNLLq5nlIlBipKDedfVvJ
key:                  regex-pcre-0.95.0.0-IfNLLq5nlIlBipKDedfVvJ
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             PCRE Backend for "Text.Regex" (regex-base)
description:
    This package provides a <http://pcre.org/ PCRE> backend for the <//hackage.haskell.org/package/regex-base regex-base> API.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  7d34372eaf3024479d280f2e4e43fbbd
exposed:              True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap

hidden-modules:       Paths_regex_pcre
import-dirs:          /usr/lib/ghc-8.8.1/site-local/regex-pcre-0.95.0.0
library-dirs:         /usr/lib/ghc-8.8.1/site-local/regex-pcre-0.95.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/regex-pcre-0.95.0.0
hs-libraries:         HSregex-pcre-0.95.0.0-IfNLLq5nlIlBipKDedfVvJ
extra-libraries:      pcre
depends:
    array-0.5.4.0 base-4.13.0.0 bytestring-0.10.9.0 containers-0.6.2.1
    regex-base-0.94.0.0-Ky6FcK1TpYXETOqiUMKde

haddock-interfaces:   /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html:         /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-pcre-0.95.0.0-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-pcre.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 regex-pcre
version:              0.95.0.0
visibility:           public
id:                   regex-pcre-0.95.0.0-5pa2SImOUG8GxGH5JPhQlP
key:                  regex-pcre-0.95.0.0-5pa2SImOUG8GxGH5JPhQlP
license:              BSD-3-Clause
copyright:            Copyright (c) 2006, Christopher Kuklewicz
maintainer:           hvr@gnu.org
author:               Christopher Kuklewicz
synopsis:             PCRE Backend for "Text.Regex" (regex-base)
description:
    This package provides a <http://pcre.org/ PCRE> backend for the <//hackage.haskell.org/package/regex-base regex-base> API.

    See also <https://wiki.haskell.org/Regular_expressions> for more information.

category:             Text
abi:                  e28b67e558888927b697357293d4fd5f
exposed:              True
exposed-modules:
    Text.Regex.PCRE Text.Regex.PCRE.ByteString
    Text.Regex.PCRE.ByteString.Lazy Text.Regex.PCRE.Sequence
    Text.Regex.PCRE.String Text.Regex.PCRE.Wrap

hidden-modules:       Paths_regex_pcre
import-dirs:          /usr/lib/ghc-8.8.3/site-local/regex-pcre-0.95.0.0
library-dirs:         /usr/lib/ghc-8.8.3/site-local/regex-pcre-0.95.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/regex-pcre-0.95.0.0
hs-libraries:         HSregex-pcre-0.95.0.0-5pa2SImOUG8GxGH5JPhQlP
extra-libraries:      pcre
depends:
    array-0.5.4.0 base-4.13.0.0 bytestring-0.10.10.0 containers-0.6.2.1
    regex-base-0.94.0.0-DXu8ShLVgKTKig28mYwARV

haddock-interfaces:   /usr/share/doc/haskell-regex-pcre/html/regex-pcre.haddock
haddock-html:         /usr/share/doc/haskell-regex-pcre/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
